import react, { useEffect, useState } from 'react';
import { lon2tile, lat2tile } from '../../lib/geo';
import dispatch from '../../workers/dispatcher-main';
import { TileKeyObject, Rectangle, Point } from './types';

import css from './Trkseg.module.css';

export interface TrksegProperties {
  id: string;
  keyObject: TileKeyObject;
  zoom: number;
  viewPort: Rectangle;
}

export const Trkseg: react.FC<TrksegProperties> = (props: TrksegProperties) => {
  const [trkseg, setTrkseg] = useState<any>([]);
  useEffect(() => {
    const getTrkseg = async () => {
      const trk = await dispatch({
        action: 'getTrkseg',
        params: {
          id: props.id,
        },
      });
      console.log(`<Trkseg>, gpx: ${JSON.stringify(trk)}`);
      setTrkseg(trk);
    };
    getTrkseg();
  }, [props.id]);

  const d = trkseg
    .slice(1)
    .reduce((previous: string, current: any, index: number) => {
      const action = index === 0 ? 'M' : index === 1 ? 'L' : '';
      const trkpt = current.doc.doc;
      return `${previous} ${action} ${
        (lon2tile(trkpt.$.lon, props.keyObject.zoomLevel) - props.keyObject.x) *
        256
      }, ${
        (lat2tile(trkpt.$.lat, props.keyObject.zoomLevel) - props.keyObject.y) *
        256
      }`;
    }, '');

  const widthFactor = () => {
    return 2;
    if (props.keyObject.zoomLevel <= 12) {
      return 2;
    }
    if (props.keyObject.zoomLevel <= 17) {
      return 4;
    }

    if (props.keyObject.zoomLevel <= 18) {
      return 8;
    }
    if (props.keyObject.zoomLevel <= 19) {
      return 16;
    }

    return 64;
  };

  // style={{ strokeWidth: widthFactor() / 256 / props.zoom }}
  return (
    <g>
      <path d={d} pointerEvents='none' className={css.track} />
    </g>
  );
};

export default Trkseg;
